@@ -209,6 +209,8 @@ class SagemakerFeatureStore:
         enable_online_store: bool,
         online_store_sources: List[str],
         enable_offline_store: bool,
+        description: str,
+        tags: List[Dict[str, str]],
         s3_uri_offline_store_output: str = None,
     ):
         """
@@ -267,6 +269,20 @@ class SagemakerFeatureStore:
         ):
             enable_online_store = False
 
+        # Validate input
+        if not description:
+            raise ValueError(
+                "Description is required for the feature group (128 charaters max). Describe how often it's updated and how it's generated."
+            )
+        if not tags:
+            raise ValueError(
+                "Tags are required to add labels to a feature group. "
+                + "Must include: [{'type': 'real-time/batch'}, {'schedule': 'event-based/daily/5m/6h'}, {'storage': 'online-only/online-offline/offline'}]"
+            )
+        else:
+            if "redis" in online_store_sources:
+                tags.append({"online-store": "redis"})
+
         # Feature group creation
         feature_group.create(
             s3_uri=(
@@ -276,6 +292,8 @@ class SagemakerFeatureStore:
             event_time_feature_name=event_time_feature_name,
             role_arn=self.role,
             enable_online_store=enable_online_store,
+            description=description,
+            tags=tags,
         )
 
         print(f'Creating "{feature_group_name}" Feature Group..')
